yakumo.neutron.v2.vpn.ipsec_site_connection.Manager

Package yakumo :: Package neutron :: Package v2 :: Package vpn :: Module ipsec_site_connection :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for VPN IPSec site connections in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for VPN IPSec site connections in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.vpn.ipsec_site_connection.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, peer_address=`'``__UNDEF__``'`, peer_id=`'``__UNDEF__``'`, local_ep_group_id=`'``__UNDEF__``'`, peer_ep_group_id=`'``__UNDEF__``'`, peer_cidrs=`'``__UNDEF__``'`, route_mode=`'``__UNDEF__``'`, mtu=`'``__UNDEF__``'`, auth_mode=`'``__UNDEF__``'`, psk=`'``__UNDEF__``'`, initiator=`'``__UNDEF__``'`, ikepolicy=`'``__UNDEF__``'`, ipsecpolicy=`'``__UNDEF__``'`, vpnservice=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, dpd=`'``__UNDEF__``'`, action=`'``__UNDEF__``'`, interval=`'``__UNDEF__``'`, timeout=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) Create an IPSec site connection | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``ipsec_site_connection``'``
| _json_resources_key = ``'``ipsec_site_connections``'``
| _url_resource_path = ``'``/v2.0/vpn/ipsec-site-connections``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, peer_address=`'``__UNDEF__``'`, peer_id=`'``__UNDEF__``'`, local_ep_group_id=`'``__UNDEF__``'`, peer_ep_group_id=`'``__UNDEF__``'`, peer_cidrs=`'``__UNDEF__``'`, route_mode=`'``__UNDEF__``'`, mtu=`'``__UNDEF__``'`, auth_mode=`'``__UNDEF__``'`, psk=`'``__UNDEF__``'`, initiator=`'``__UNDEF__``'`, ikepolicy=`'``__UNDEF__``'`, ipsecpolicy=`'``__UNDEF__``'`, vpnservice=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, dpd=`'``__UNDEF__``'`, action=`'``__UNDEF__``'`, interval=`'``__UNDEF__``'`, timeout=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
Create an IPSec site connection Parameters: `name` (str) - IPSec site connection name `description` (str) - Description `peer_address` (str) - Peer address `peer_id` (str) - Peer ID `local_ep_group_id` (str) - Local EP group ID `peer_ep_group_id` (str) - Peer EP group ID `peer_cidrs` (str) - Peer CIDRs `route_mode` (str) - Route mode `mtu` (int) - MTU `auth_mode` (str) - Auth mode `psk` (str) - PSK `initiator` (str) - Initiator `ikepolicy` (str) - IKE policy `ipsecpolicy` (str) - IPSec policy `vpnservice` (str) - VPN service `project` (yakumo.project.Resource) - Project `dpd` (str) - DPD `action` (str) - Action `interval` (str) - Interval `timeout` (int) - Timeout `is_enabled` (bool) - Whether the connection is enabled Returns: yakumo.neutron.v2.vpn.ipsec_site_connection.Resource Created connection Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('peer_address', 'peer_address', map
      per.Noop), ('peer_id', 'peer_id', mapper.Noop), ('local_ep_group_id',
      'local_ep_group_id', mapper.Noop), ('peer_ep_group_id', 'peer_ep_group
      _id', mapper.Noop), ('peer_cidrs', 'peer_cidrs', mapper.Noop), ('route
      _mode', 'route_mode', mapper.Noop), ('mtu', 'mtu', mapper.Noop), ('aut
      h_mode', 'auth_mode', mapper.Noop), ('psk', 'psk', mapper.Noop), ('ini
      tiator', 'initiator', mapper.Noop), ('ikepolicy', 'ikepolicy_id', mapp
      ...